package main

import (
	"fmt"
	"log"
	"os"
	"strings"

	"git.crumpington.com/public/am/amclient"
)

func main() {
	usage := func() {
		fmt.Fprintf(
			os.Stderr,
			"\n\n%s <URL> <api_key> <action> [text]\n\n"+
				"Action is one of `ping`, `log`, or `alert`.\n"+
				"The `log` and `alert` actions require `text`.\n\n",
			os.Args[0])
		os.Exit(1)
	}

	if len(os.Args) < 4 {
		usage()
	}

	url := os.Args[1]
	apiKey := os.Args[2]

	cl := amclient.New(url, apiKey)

	action := os.Args[3]

	var err error

	switch action {
	case "ping":
		err = cl.Ping()

	case "log":
		if len(os.Args) < 5 {
			usage()
		}
		err = cl.Log(strings.Join(os.Args[4:], " "))

	case "alert":
		if len(os.Args) < 5 {
			usage()
		}
		err = cl.Alert(strings.Join(os.Args[4:], " "))

	default:
		usage()
	}

	if err != nil {
		log.Fatalf("Error: %v", err)
	}
}
